@@ -18,8 +18,7 @@
  *  MA  02110-1301  USA
  */
 
-#ifndef __RBGPRIVATE_H__
-#define __RBGPRIVATE_H__
+#pragma once
 
 /*
  * CentOS 6: GLib 2.28
@@ -123,6 +122,13 @@ G_GNUC_INTERNAL void rg_enum_add_constants(VALUE mod, GType enum_type, const gch
 G_GNUC_INTERNAL void rg_flags_add_constants(VALUE mod, GType flags_type, const gchar *strip_prefix);
 G_GNUC_INTERNAL char *rg_obj_constant_lookup(const char *name);
 
+G_GNUC_INTERNAL VALUE rbg_gc_marker_new(void);
+G_GNUC_INTERNAL void rbg_gc_marker_guard(VALUE rb_gc_marker,
+                                         VALUE rb_object);
+G_GNUC_INTERNAL void rbg_gc_marker_unguard(VALUE rb_gc_marker,
+                                           VALUE rb_object);
+G_GNUC_INTERNAL void rbg_gc_marker_unguard_all(VALUE rb_gc_marker);
+
 G_GNUC_INTERNAL void Init_glib_gc(void);
 
 G_GNUC_INTERNAL void Init_gutil(void);
@@ -189,5 +195,3 @@ G_GNUC_INTERNAL void Init_gobject_gtypemodule(void);
 G_GNUC_INTERNAL void Init_gobject_gbinding(void);
 
 G_END_DECLS
-
-#endif
